summaryrefslogtreecommitdiff
path: root/gs/src/gscpm.h
diff options
context:
space:
mode:
Diffstat (limited to 'gs/src/gscpm.h')
-rw-r--r--gs/src/gscpm.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/gs/src/gscpm.h b/gs/src/gscpm.h
index fac9be2ca..a50b922d6 100644
--- a/gs/src/gscpm.h
+++ b/gs/src/gscpm.h
@@ -1,4 +1,4 @@
-/* Copyright (C) 1995 Aladdin Enterprises. All rights reserved.
+/* Copyright (C) 1995, 1998 Aladdin Enterprises. All rights reserved.
This file is part of Aladdin Ghostscript.
@@ -17,7 +17,7 @@
*/
/* Charpath mode definitions */
#ifndef gscpm_INCLUDED
# define gscpm_INCLUDED
@@ -30,4 +30,10 @@ typedef enum {
cpm_true_charboxpath /* true charboxpath (ditto) */
} gs_char_path_mode;
+typedef enum {
+ CACHE_DEVICE_NONE = 0, /* default, must be 0 */
+ CACHE_DEVICE_NOT_CACHING, /* setcachedevice done but not caching */
+ CACHE_DEVICE_CACHING /* setcachedevice done and caching */
+} gs_in_cache_device_t;
+
#endif /* gscpm_INCLUDED */
@@ -17,7 +17,7 @@
*/
-/* Charpath mode definitions */
+/* Charpath mode and cache device status definitions */
#ifndef gscpm_INCLUDED
# define gscpm_INCLUDED